@@ -1,5 +1,5 @@
 /****************************************************************************
-*    Copyright © 2014-2021 Xorg
+*    Copyright © 2014-2022 Xorg
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
@@ -53,6 +53,7 @@ const Technology_DB technology_intel[] =
 	{  5,          53,          -1,          32 }, // Atom Cloverview
 	{  5,          69,          -1,          22 }, // Haswell
 	{  5,          85,          -1,          14 }, // Skylake (Xeon Scalable)
+	{  5,          165,          6,          14 }, // Comet Lake
 	{  6,           6,           6,         250 }, // PII Dixon / Celeron Mendocino
 	{  6,           6,          15,          65 }, // P4 Cedar Mill / PD Presler
 	{  6,          22,          -1,          65 }, // C2 Conroe-L
@@ -77,6 +78,7 @@ const Technology_DB technology_intel[] =
 	{ 12,          44,          -1,          32 }, // Westmere
 	{ 12,          60,          -1,          22 }, // Haswell
 	{ 12,          76,          -1,          14 }, // Atom Cherry Trail
+	{ 12,         140,          -1,          10 }, // Tiger Lake
 	{ 13,          13,          -1,          90 }, // Pentium M Dothan
 	{ 13,          45,          -1,          32 }, // Sandy Bridge-E
 	{ 13,          61,          -1,          14 }, // Broadwell-U
@@ -133,6 +135,7 @@ const Technology_DB technology_amd[] =
 	{ -1,          24,          23,          12 }, // Zen+ (Picasso)
 	{ -1,          49,          23,           7 }, // Zen 2 (Rome/Castle Peak)
 	{ -1,          96,          23,           7 }, // Zen 2 (Renoir)
+	{ -1,         104,          23,           7 }, // Zen 2 (Lucienne)
 	{ -1,         113,          23,           7 }, // Zen 2 (Matisse)
 	{ -1,          33,          25,           7 }, // Zen 3 (Vermeer)
 	{ -1,          80,          25,           7 }, // Zen 3 (Cezanne)
@@ -160,6 +163,7 @@ const Package_DB package_intel[] =
 	{ "Pentium D (SmithField)",         NULL,                               "LGA 775"        },
 	{ "Pentium D (Presler)",            NULL,                               "LGA 775"        },
 	{ "Bloomfield",                     NULL,                               "LGA 1366"       },
+	{ NULL,                             "Intel(R) Core(TM)2 Duo CPU E7400", "LGA 775"        },
 	{ NULL,                             "Intel(R) Core(TM) i5-2520M CPU",   "rPGA 988B"      },
 	{ NULL,                             "Intel(R) Xeon(R) CPU E31275",      "LGA 1155"       },
 	{ NULL,                             "Intel(R) Core(TM) i7-2860QM CPU",  "rPGA 988B"      },
@@ -173,6 +177,9 @@ const Package_DB package_intel[] =
 	{ NULL,                             "Intel(R) Core(TM) i7-8550U CPU",   "FCBGA 1356"     },
 	{ NULL,                             "Intel(R) Core(TM) i7-8650U CPU",   "FCBGA 1356"     },
 	{ NULL,                             "Intel(R) Core(TM) i9-9900K CPU",   "LGA 1151"       },
+	{ NULL,                             "Intel(R) Core(TM) i5-1135G7",      "FCBGA 1449"     },
+	{ NULL,                             "Intel(R) Core(TM) i7-1165G7",      "FCBGA 1449"     },
+	{ NULL,                             "Intel(R) Core(TM) i7-11700K",      "LGA 1200"       },
 	{ NULL,                             NULL,                               NULL             }
 	//Codename                          Model                               Socket
 };
@@ -186,21 +193,29 @@ const Package_DB package_amd[] =
 	{ "Trinity X4",                     NULL,            "FM2 (PGA-ZIF)"  },
 	{ "Turion X2",                      "TL",            "S1g1 (PGA-ZIF)" },
 	{ "Turion X2",                      "TK",            "S1g1 (PGA-ZIF)" },
-	{ "Deneb",    "AMD Phenom(tm) II X4 945",            "AM3 (PGA-938"   },
+	{ "Deneb",    "AMD Phenom(tm) II X4 945",            "AM3 (PGA-938)"  },
+	{ "Athlon II X4 (Propus)",          NULL,            "AM3 (PGA-938)"  },
 	{ "Zambezi",                        NULL,            "AM3+ (PGA-942)" },
 	{ "Vishera",                        NULL,            "AM3+ (PGA-942)" },
 	/* Zen */
+	{ "Raven Ridge",                    NULL,            "FP5 (BGA-1140)"   },
 	{ "Summit Ridge",                   NULL,            "AM4 (PGA-1331)"   },
 	{ "Whitehaven",                     NULL,            "SP3r2 (LGA-4094)" },
 	{ "Naples",                         NULL,            "SP3 (LGA-4094)"   },
 	/* Zen+ */
-	{ "Picasso",                        NULL,            "FP5 (BGA)"        },
+	{ "Picasso",                        NULL,            "FP5 (BGA-1140)"   },
 	{ "Pinnacle Ridge",                 NULL,            "AM4 (PGA-1331)"   },
 	{ "Colfax",                         NULL,            "SP3r2 (LGA-4094)" },
 	/* Zen 2 */
+	{ "Renoir",                         NULL,            "FP6 (BGA-1140)"   },
+	{ "Lucienne",                       NULL,            "FP6 (BGA-1140)"   },
 	{ "Matisse",                        NULL,            "AM4 (PGA-1331)"   },
 	{ "Castle Peak",                    NULL,            "SP3r2 (LGA-4094)" },
 	{ "Rome",                           NULL,            "SP3 (LGA-4094)"   },
+	/* Zen 3 */
+	{ "Cezanne",                        NULL,            "FP6 (BGA-1140)"   },
+	{ "Vermeer",                        NULL,            "AM4 (PGA-1331)"   },
+	{ "Milan",                          NULL,            "SP3 (LGA-4094)"   },
 	{ NULL,                             NULL,            NULL               }
 	//Codename                          Model            Socket
 };
