@@ -1,5 +1,5 @@
 /****************************************************************************
-*    Copyright © 2014-2021 Xorg
+*    Copyright © 2014-2022 Xorg
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
@@ -89,7 +89,7 @@ static const char *objectsys_bar[LASTBAR] =
 /* Tab Graphics */
 static const char *objectgpu[GPUFIELDS] =
 {
-	"card0_vend", "card0_driver", "card0_umd", "card0_mod", "card0_did_rid", "card0_pcie", "card0_temp", "card0_usage", "card0_gvolt", "card0_gpwr", "card0_gclk", "card0_mclk", "card0_vram_used"
+	"card0_vend", "card0_driver", "card0_umd", "card0_mod", "card0_comp_unit", "card0_did_rid", "card0_pcie", "card0_temp", "card0_usage", "card0_gvolt", "card0_gpwr", "card0_gclk", "card0_mclk", "card0_vram_used", "card0_rebar"
 };
 
 /* Tab Bench */
