@@ -1,5 +1,5 @@
 /****************************************************************************
-*    Copyright © 2014-2021 Xorg
+*    Copyright © 2014-2022 Xorg
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
@@ -262,6 +262,12 @@ void start_tui_ncurses(Labels *data)
 /* Convert keys when an alternative mapping is used */
 #define ALT_CODE 27
 #define ALT(x)   (x & ALT_CODE)
+
+/* glibc's term.h pulls in sys/ttydefaults.h which has it, but musl's does not. */
+#ifndef CTRL
+#define CTRL(x)	(x&037)
+#endif
+
 static int convert_char(int ch)
 {
 	int i = 0;
@@ -777,14 +783,14 @@ static void print_activecard(WINDOW *win, const SizeInfo info, Labels *data)
 	if(data->gpu_count == 0)
 		return;
 
-	mvwprintwc(win, LINE_12, info.tb + 1, DEFAULT_COLOR, "#%i: %s", opts->selected_gpu, data->tab_graphics[VALUE][GPU1MODEL + opts->selected_gpu * GPUFIELDS]);
+	mvwprintwc(win, LINE_13, info.tb + 1, DEFAULT_COLOR, "#%i: %s", opts->selected_gpu, data->tab_graphics[VALUE][GPU1MODEL + opts->selected_gpu * GPUFIELDS]);
 	wrefresh(win);
 }
 
 /* Graphics tab */
 static void ntab_graphics(WINDOW *win, const SizeInfo info, Labels *data)
 {
-	int i, j, line, start = LINE_0, end = LINE_10;
+	int i, j, line, start = LINE_0, end = LINE_11;
 
 	if(data->gpu_count == 0)
 		return;
@@ -800,10 +806,8 @@ static void ntab_graphics(WINDOW *win, const SizeInfo info, Labels *data)
 			case GPU1USAGE:
 			case GPU1MEMCLOCK:
 			case GPU1POWERAVG:
-				mvwprintw2c(win, line - 1, info.tm, "%18s: %s", data->tab_graphics[NAME][i], data->tab_graphics[VALUE][i]);
-				break;
 			case GPU1DIDRID:
-				mvwprintw2c(win, line++, info.tm, "%18s: %s", data->tab_graphics[NAME][i], data->tab_graphics[VALUE][i]);
+				mvwprintw2c(win, line - 1, info.tm, "%18s: %s", data->tab_graphics[NAME][i], data->tab_graphics[VALUE][i]);
 				break;
 			default:
 				mvwprintw2c(win, line++, info.tb, "%13s: %s", data->tab_graphics[NAME][i], data->tab_graphics[VALUE][i]);
